@@ -9,5 +9,6 @@ calc_metrics <- function(beta, qt, qy_t, hy, px, qt_x, quiet = TRUE){
     message('H(T) = ', ht, ', H(Y|T) = ', hy_t, ', I(Y,T) = ', iyt,
             ', I(X,T) = ', ixt, '\n')
   }
-  return(list(ht, ht_x, iyt, ixt))
+  return(list('ht' = ht, 'ht_x' = ht_x, 
+              'iyt' = iyt, 'ixt' = ixt))
 }
